\name{HiC_HMRF_Bayes_File}
\alias{HiC_HMRF_Bayes_File}

\title{
Hi-C HMRF Bayes Peak Caller from File Input to File Output
}
\description{
This is the pipeline function helps researchers conduct Hi-C HMRF Bayes peak calling from loading input data file to outputting results in one function. It performs three steps: (1) load Hi-C data by the function \code{HiC_Prepare_Matrix}, (2) conduct Hi-C HMRF Bayes peak calling method by the function \code{HiC_HMRF_Bayes}, and (3) write Hi-C results of estimated peak probabilities and parameters respectively into different text files by the function \code{HiC_Output}. 
The input file is specified by file parameter, which is a text file, with 4 columns respectively as fragment 1, fragment 2, observed frequency and expected frequency. 
The prob result file is specified by probfile parameter, which is a text file, with 5 columns respectively as fragment 1, fragment 2, observed frequency, expected frequency and peak probability.
The estimator result file is specified by "estimatorfile" parameter, which is a text file including values of estimated phi, theta and psi in our model specification. 
}
\usage{
HiC_HMRF_Bayes_File(file, probfile, estimatorfile, 
	sep = "\t", header = TRUE, verbose = TRUE, burnIn = 5000, iter = 5000)
}

\arguments{
  \item{file}{
    the file to be loaded, which is a text file, with 4 columns respectively as fragment 1, fragment 2, observed frequency and expected frequency. 
}
  \item{probfile}{
	the file to output the estimated peak probability matrix by HiC-HMRF-Bayes method, either a character string naming a file or a connection open for writing. "" indicates output to the console. The prob file is a text file with 5 columns respectively as fragment 1, fragment 2, observed frequencies, expected frequencies and peak probabilities.
}
  \item{estimatorfile}{
   the file to output the estimated parameters of theta, phi and psi by HiC-HMRF-Bayes method, either a character string naming a file or a connection open for writing. "" indicates output to the console.
}
  \item{sep}{
   the field separator character. Values on each line of the file are separated by this character for the data loading step by the function \code{HiC_Prepare_Matrix}.
}
  \item{header}{
   a logical value indicating whether the file contains the names of the variables as its first line for the data loading step by the function \code{HiC_Prepare_Matrix}. If missing, the value is determined from the file format: header is set to TRUE if and only if the first row contains one fewer field than the number of columns.
}
  \item{verbose}{
   a logical value controlling whether some information should be outputted. If it is true, the number of HiC records loaded will be reported in data loading step by \code{HiC_Prepare_Matrix} will be reported and the intermediate results of estimated parameters for each 200 simulations in peak calling by the function \code{HiC_HMRF_Bayes} will be reported.
}
  \item{burnIn}{
   the number of burn-ins for the function {HiC_HMRF_Bayes} called internally. For example, if burnin=4000 and iter=8000, out HiC-HMRF-Bayes will run 12000 simulations.
}
  \item{iter}{
  the number of simulations after the burn-ins for the function {HiC_HMRF_Bayes} called internally. For example, if burnin=4000 and iter=8000, out HiC-HMRF-Bayes will run 12000 simulations.
}
}
\details{
This is the pipeline function helps researchers conduct Hi-C HMRF Bayes peak calling from loading input data file to outputting results in one function. It performs three steps: (1) load Hi-C data by the function \code{HiC_Prepare_Matrix}, (2) conduct Hi-C HMRF Bayes peak calling method by the function \code{HiC_HMRF_Bayes}, and (3) write Hi-C results of estimated peak probabilities and parameters respectively into different text files by the function \code{HiC_Output}. 
The input file is specified by file parameter, which is a text file, with 4 columns respectively as fragment 1, fragment 2, observed frequency and expected frequency. 
The prob result file is specified by probfile parameter, which is a text file, with 5 columns respectively as fragment 1, fragment 2, observed frequency, expected frequency and peak probability.
The estimator result file is specified by "estimatorfile" parameter, which is a text file including values of estimated phi, theta and psi in our model specification. 

When the data does not follow correct data format: (1) not same columns for each line in the input file, (2) observed frequencies contain NA or (3) expected frequencies contain NA or 0 values, the function will stop and output the information, asking the researchers to check data format.
}

\value{
No return values. The function will output the results in the specified probfile and estimatorfile.
}
\references{
Xu et al, A hidden Markov random field based Bayesian method for the detection of long-range chromosomal interactions in Hi-C Data, Manuscript.
}
\author{
Zheng Xu
}

\examples{
## An example of loading data, run peak caller and output results. 
## Our toy example of HiC data for fragment 15060-15069.

##  Conduct Hi-C HMRF in three steps.
## (1) loading data, (2) peak calling and (3) outputting results.
HiC.Data=HiC_Prepare_Matrix(file="toyHiC_frag15060_15069.txt",
	verbose=TRUE,sep="\t",header=TRUE)
HiC.Results=HiC_HMRF_Bayes(HiC.Data$ObservedCountMatrix, 
	HiC.Data$ExpectedCountMatrix, burnIn = 5000, iter = 5000, verbose=1)
HiC_Output(HiCResults=HiC.Results,fragIDs=HiC.Data$fragIDs,
	probfile="toyHiC_frag15060_15069_Results.txt",
	estimatorfile="toyHiC_frag15060_15069_Estimated_Parameters.txt")

## Conduct Hi-C HMRF in one function for all.
HiC_HMRF_Bayes_File(file="toyHiC_frag15060_15069.txt",
	probfile="toyHiC_frag15060_15069_Results.txt", 
	estimatorfile="toyHiC_frag15060_15069_Estimated_Parameters.txt",
	sep="\t",header=TRUE, verbose=TRUE, burnIn = 5000, iter = 5000)
}
\keyword{HiC_HMRF_Bayes_File}

